aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/argaze/utils/export_tobii_segment_aruco_visual_scan.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/argaze/utils/export_tobii_segment_aruco_visual_scan.py b/src/argaze/utils/export_tobii_segment_aruco_visual_scan.py
index 04e21d6..9ca836b 100644
--- a/src/argaze/utils/export_tobii_segment_aruco_visual_scan.py
+++ b/src/argaze/utils/export_tobii_segment_aruco_visual_scan.py
@@ -41,7 +41,7 @@ def main():
if args.marker_id_scene == None:
print(f'Track any Aruco markers from the {args.marker_dictionary} dictionary')
else:
- print(f'Track Aruco markers {args.marker_id_scene.keys()} from the {args.marker_dictionary} dictionary')
+ print(f'Track Aruco markers {list(args.marker_id_scene.keys())} from the {args.marker_dictionary} dictionary')
# Manage destination path
destination_path = '.'
@@ -187,11 +187,11 @@ def main():
try:
- # Get closest gaze position before video timestamp and remove all gaze positions before
- closest_gaze_ts, closest_gaze_position = tobii_ts_gaze_positions.pop_first_until(video_ts)
+ # Get nearest gaze position before video timestamp and remove all gaze positions before
+ nearest_gaze_ts, nearest_gaze_position = tobii_ts_gaze_positions.pop_first_until(video_ts)
# Draw gaze position
- video_gaze_pixel = (int(closest_gaze_position.value[0] * video_frame.width), int(closest_gaze_position.value[1] * video_frame.height))
+ video_gaze_pixel = (int(nearest_gaze_position.value[0] * video_frame.width), int(nearest_gaze_position.value[1] * video_frame.height))
cv.circle(video_frame.matrix, video_gaze_pixel, 4, (0, 255, 255), -1)
# Store gaze position at this time in millisecond